@@ -1,3 +1,5 @@
+use super::Iconize;
+use crate::Icon;
 use std::fmt;
 
 pub struct BacklightFormatter {
@@ -14,6 +16,12 @@ impl BacklightFormatter {
     }
 }
 
+impl Iconize for BacklightFormatter {
+    fn set_icon(&self, icon: &mut Icon) {
+        icon.find_icon("display-brightness-symbolic")
+    }
+}
+
 impl fmt::Display for BacklightFormatter {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         return write!(f, "{}%", self.percentage);
