@@ -9,6 +9,7 @@ use libmacchina::traits::NetworkReadout as _;
 use libmacchina::traits::ReadoutError;
 use libmacchina::{BatteryReadout, GeneralReadout, MemoryReadout, NetworkReadout};
 
+use crate::config::Config;
 use crate::fmt::backlight::BacklightFormatter;
 use crate::fmt::battery::BatteryFormatter;
 use crate::fmt::date::DateFormatter;
@@ -29,18 +30,25 @@ pub fn uptime(icon: &mut Icon) -> Result<String, ReadoutError> {
     Ok(fmt.to_string())
 }
 
-pub fn network(interface: Option<&str>, icon: &mut Icon) -> Result<String, ReadoutError> {
+pub fn network(config: Option<&Config>, icon: &mut Icon) -> Result<String, ReadoutError> {
     let mut fmt = NetworkFormatter::new();
     let readout = NetworkReadout::new();
 
-    fmt.set_logical_address(readout.logical_address(interface)?);
+    if let Some(conf) = config {
+        if let Some(network) = conf.get_network() {
+            if let Some(interface) = network.get_interface() {
+                let ifname = Some(interface.as_str());
+                fmt.set_logical_address(readout.logical_address(ifname)?);
 
-    if let Ok(rx_bytes) = readout.rx_bytes(interface) {
-        fmt.set_rx_bytes(rx_bytes);
-    }
+                if let Ok(rx_bytes) = readout.rx_bytes(ifname) {
+                    fmt.set_rx_bytes(rx_bytes);
+                }
 
-    if let Ok(tx_bytes) = readout.tx_bytes(interface) {
-        fmt.set_tx_bytes(tx_bytes);
+                if let Ok(tx_bytes) = readout.tx_bytes(ifname) {
+                    fmt.set_tx_bytes(tx_bytes);
+                }
+            }
+        }
     }
 
     fmt.set_icon(icon);
@@ -81,22 +89,33 @@ pub fn backlight(icon: &mut Icon) -> Result<String, ReadoutError> {
     Ok(fmt.to_string())
 }
 
-pub fn date(railway: bool, icon: &mut Icon) -> Result<String, ReadoutError> {
+pub fn date(config: Option<&Config>, icon: &mut Icon) -> Result<String, ReadoutError> {
     let mut fmt = DateFormatter::new();
     if let Some(readout) = helpers::utc_from_timezone() {
+        let hour = readout.hour12();
         fmt.set_weekday(readout.weekday());
         fmt.set_month(readout.month());
         fmt.set_day(readout.day());
         fmt.set_minute(readout.minute());
+        fmt.set_meridiem(hour.0);
+        fmt.set_hour(hour.1);
 
-        if railway {
-            fmt.set_hour(readout.hour());
-            fmt.enable_railway();
-        } else {
-            let h = readout.hour12();
-            fmt.set_meridiem(h.0);
-            fmt.set_hour(h.1);
-        };
+        if let Some(conf) = config {
+            if let Some(date) = conf.get_date() {
+                if date.is_railway() {
+                    let hour = readout.hour();
+                    fmt.set_hour(hour);
+                } else {
+                    let hour = readout.hour12();
+                    fmt.set_meridiem(hour.0);
+                    fmt.set_hour(hour.1);
+                }
+
+                if let Some(format) = date.get_format() {
+                    fmt.from_config(format);
+                }
+            }
+        }
 
         fmt.set_icon(icon);
 
